From 3da780b85ff2bf4f8117d72711beb6c697ef7e40 Mon Sep 17 00:00:00 2001
From: Peter Geoghegan <pg@bowt.ie>
Date: Thu, 10 Mar 2022 19:46:30 -0800
Subject: [PATCH v3 2/2] vacuumlazy.c: Rename nblocks to rel_pages.

It seems worth being consistent about referring to VACUUM's rel_pages
field consistently, so rename the local variable copy used by
lazy_scan_heap to rel_pages for consistency.

Author: Peter Geoghegan <pg@bowt.ie>
Reviewed-By: Andres Freund <andres@anarazel.de>
Discussion: https://postgr.es/m/20220311031351.sbge5m2bpvy2ttxg@alap3.anarazel.de
---
 src/backend/access/heap/vacuumlazy.c | 22 +++++++++++-----------
 1 file changed, 11 insertions(+), 11 deletions(-)

diff --git a/src/backend/access/heap/vacuumlazy.c b/src/backend/access/heap/vacuumlazy.c
index 79089622a..e72058873 100644
--- a/src/backend/access/heap/vacuumlazy.c
+++ b/src/backend/access/heap/vacuumlazy.c
@@ -829,7 +829,7 @@ static void
 lazy_scan_heap(LVRelState *vacrel, int nworkers)
 {
 	VacDeadItems *dead_items;
-	BlockNumber nblocks = vacrel->rel_pages,
+	BlockNumber rel_pages = vacrel->rel_pages,
 				blkno,
 				next_unskippable_block,
 				next_failsafe_block,
@@ -862,7 +862,7 @@ lazy_scan_heap(LVRelState *vacrel, int nworkers)
 
 	/* Report that we're scanning the heap, advertising total # of blocks */
 	initprog_val[0] = PROGRESS_VACUUM_PHASE_SCAN_HEAP;
-	initprog_val[1] = nblocks;
+	initprog_val[1] = rel_pages;
 	initprog_val[2] = dead_items->max_items;
 	pgstat_progress_update_multi_param(3, initprog_index, initprog_val);
 
@@ -886,9 +886,9 @@ lazy_scan_heap(LVRelState *vacrel, int nworkers)
 	 * Before entering the main loop, establish the invariant that
 	 * next_unskippable_block is the next block number >= blkno that we can't
 	 * skip based on the visibility map, either all-visible for a regular scan
-	 * or all-frozen for an aggressive scan.  We set it to nblocks if there's
-	 * no such block.  We also set up the skipping_blocks flag correctly at
-	 * this stage.
+	 * or all-frozen for an aggressive scan.  We set it to rel_pages when
+	 * there's no such block.  We also set up the skipping_blocks flag
+	 * correctly at this stage.
 	 *
 	 * Note: The value returned by visibilitymap_get_status could be slightly
 	 * out-of-date, since we make this test before reading the corresponding
@@ -906,7 +906,7 @@ lazy_scan_heap(LVRelState *vacrel, int nworkers)
 	next_unskippable_block = 0;
 	if (vacrel->skipwithvm)
 	{
-		while (next_unskippable_block < nblocks)
+		while (next_unskippable_block < rel_pages)
 		{
 			uint8		vmstatus;
 
@@ -933,7 +933,7 @@ lazy_scan_heap(LVRelState *vacrel, int nworkers)
 	else
 		skipping_blocks = false;
 
-	for (blkno = 0; blkno < nblocks; blkno++)
+	for (blkno = 0; blkno < rel_pages; blkno++)
 	{
 		Buffer		buf;
 		Page		page;
@@ -951,7 +951,7 @@ lazy_scan_heap(LVRelState *vacrel, int nworkers)
 			next_unskippable_block++;
 			if (vacrel->skipwithvm)
 			{
-				while (next_unskippable_block < nblocks)
+				while (next_unskippable_block < rel_pages)
 				{
 					uint8		vmskipflags;
 
@@ -996,7 +996,7 @@ lazy_scan_heap(LVRelState *vacrel, int nworkers)
 			/*
 			 * The current page can be skipped if we've seen a long enough run
 			 * of skippable blocks to justify skipping it -- provided it's not
-			 * the last page in the relation (according to rel_pages/nblocks).
+			 * the last page in the relation (according to rel_pages).
 			 *
 			 * We always scan the table's last page to determine whether it
 			 * has tuples or not, even if it would otherwise be skipped. This
@@ -1004,7 +1004,7 @@ lazy_scan_heap(LVRelState *vacrel, int nworkers)
 			 * on the table to attempt a truncation that just fails
 			 * immediately because there are tuples on the last page.
 			 */
-			if (skipping_blocks && blkno < nblocks - 1)
+			if (skipping_blocks && blkno < rel_pages - 1)
 			{
 				/*
 				 * Tricky, tricky.  If this is in aggressive vacuum, the page
@@ -1371,7 +1371,7 @@ lazy_scan_heap(LVRelState *vacrel, int nworkers)
 	vacrel->blkno = InvalidBlockNumber;
 
 	/* now we can compute the new value for pg_class.reltuples */
-	vacrel->new_live_tuples = vac_estimate_reltuples(vacrel->rel, nblocks,
+	vacrel->new_live_tuples = vac_estimate_reltuples(vacrel->rel, rel_pages,
 													 vacrel->scanned_pages,
 													 vacrel->live_tuples);
 
-- 
2.30.2

